==> sigaddons-7.0.21.12.14.tar.gz: sigaddons-7.0.21.12.14/sigaddons/dusal_web_tree_image/__openerp__.py <==
# -*- coding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    This module copyright (C) 2014 Therp BV (<http://therp.nl>).
#
#    Snippet from https://github.com/hsd/listview_images
#    Copyright (C) 2013 Marcel van der Boom <marcel@hsdev.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################
{
    "name": "Show images in tree views",
    'version': '7.0.21.12.14',
    "author": "Dusal Solutions,Therp BV,Odoo Community Association (OCA)",
    'url': 'https://github.com/OCA/Web',
    'license': 'AGPL-3',
    'category': 'Web',
    'description': 'Implementacao de imagens na tree',
    'icon': "/dusal_web_tree_image/static/description/icon.png",
    'depends': [
        'web',
    ],
    'js': [
           'static/src/js/web_tree_image.js'
    ],
    'qweb': [
        'static/src/xml/widget.xml',
    ],
}

==> sigaddons-7.0.2310.2.tar.gz: sigaddons-7.0.2310.2/sigaddons/dusal_web_tree_image/__openerp__.py <==
# -*- coding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    This module copyright (C) 2014 Therp BV (<http://therp.nl>).
#
#    Snippet from https://github.com/hsd/listview_images
#    Copyright (C) 2013 Marcel van der Boom <marcel@hsdev.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################
{
    "name": "Show images in tree views",
    'version': '7.0.2310.2',
    "author": "Dusal Solutions,Therp BV,Odoo Community Association (OCA)",
    'url': 'https://github.com/OCA/Web',
    'license': 'AGPL-3',
    'category': 'Web',
    'description': 'Implementacao de imagens na tree',
    'icon': "/dusal_web_tree_image/static/description/icon.png",
    'depends': [
        'web',
    ],
    'js': [
           'static/src/js/web_tree_image.js'
    ],
    'qweb': [
        'static/src/xml/widget.xml',
    ],
}
